@@ -4,7 +4,7 @@ from argparse import Namespace
 from errno import EINTR
 from errno import ENOENT
 import logging
-import os
+from logging import Logger
 import sys
 from typing import Any
 from typing import Callable
@@ -14,20 +14,11 @@ from typing import Optional
 from typing import Sequence
 from typing import Tuple
 
-from colorlog import ColoredFormatter
-
+from .attribute import __prog_name__
+from .logger import log
 from .parser import argp
 from .util import singleton
 
-DEFAULT_LOG_FORMAT = "%(log_color)s%(message)s"
-DEFAULT_LOG_COLORS = {
-    "DEBUG": "black",
-    "INFO": "white",
-    "WARNING": "yellow",
-    "ERROR": "red",
-    "CRITICAL": "light_red",
-}
-
 
 class add_command:
     '''Define a new command-line node.
@@ -292,7 +283,7 @@ class end_command:
 
 
 @singleton
-class commands:
+class commands(log):
     '''Singleton command-line tool based on argparse.
 
     Define and bind all callback functions before calling run() or parse().
@@ -304,7 +295,7 @@ class commands:
 
     >>> from xarg import add_command\n
     >>> from xarg import argp\n
-    >>> from xarg import cmds\n
+    >>> from xarg import commands\n
     >>> from xarg import end_command\n
     >>> from xarg import pre_command\n
     >>> from xarg import run_command\n
@@ -326,7 +317,7 @@ class commands:
     >>>     return 0\n
 
     >>> def main(argv: Optional[Sequence[str]] = None) -> int:\n
-    >>>     return cmds.run(\n
+    >>>     return commands().run(\n
     >>>         root=cmd,\n
     >>>         argv=argv,\n
     >>>         prog="xarg-example",\n
@@ -335,15 +326,13 @@ class commands:
 
     LOGGER_ARGUMENT_GROUP = "logger options"
 
-    def __init__(self, version: Optional[str] = None,
-                 enable_logger: bool = True):
-        assert isinstance(version, str) or version is None
-        assert isinstance(enable_logger, bool)
-        self.__prog: str = "xarg"
+    def __init__(self):
+        self.__prog: str = __prog_name__
         self.__root: Optional[add_command] = None
         self.__args: Namespace = Namespace()
-        self.__version: Optional[str] = version
-        self.__enable_logger: bool = enable_logger
+        self.__version: Optional[str] = None
+        self.__enabled_logger: bool = True
+        super().__init__()
 
     @property
     def prog(self) -> str:
@@ -385,19 +374,19 @@ class commands:
         self.__version = _version
 
     @property
-    def enable_logger(self) -> bool:
-        return self.__enable_logger
+    def enabled_logger(self) -> bool:
+        return self.__enabled_logger
 
-    @enable_logger.setter
-    def enable_logger(self, value: bool):
+    @enabled_logger.setter
+    def enabled_logger(self, value: bool):
         assert isinstance(value, bool)
-        self.__enable_logger = value
+        self.__enabled_logger = value
 
     @property
-    def logger(self) -> logging.Logger:
+    def logger(self) -> Logger:
         '''Logger.
         '''
-        return logging.getLogger(self.prog)
+        return self.get_logger(self.prog)
 
     def stdout(self, context: Any):
         '''Output string to sys.stdout.
@@ -432,10 +421,6 @@ class commands:
             return None
 
         def add_optional_level():
-
-            def get_all_level_name() -> List[str]:
-                return ["fatal", "error", "warn", "info", "debug"]
-
             group = argp.argument_group(self.LOGGER_ARGUMENT_GROUP)
             group_level = group.add_mutually_exclusive_group()
 
@@ -445,13 +430,13 @@ class commands:
                     option_level,
                     type=str,
                     nargs="?",
-                    const="info",
-                    default="info",
-                    choices=get_all_level_name(),
+                    const=self.LOG_LEVEL_INFO.lower(),
+                    default=self.LOG_LEVEL_INFO.lower(),
+                    choices=self.ALLOWED_LOG_LEVELS,
                     dest="_log_level_str_",
                     help="Logger output level, default info.")
 
-            for level in get_all_level_name():
+            for level in self.ALLOWED_LOG_LEVELS:
                 options = []
                 if isinstance(filter_optional_name(f"-{level[0]}"), str):
                     options.append(f"-{level[0]}")
@@ -498,7 +483,7 @@ class commands:
                                type=str,
                                nargs="?",
                                const=DEFAULT_LOG_FMT,
-                               default=DEFAULT_LOG_FORMAT,
+                               default=self.DEFAULT_LOG_FORMAT,
                                metavar="STRING",
                                dest="_log_format_",
                                help="Logger output format.")
@@ -523,43 +508,32 @@ class commands:
                                        dest="_log_console_",
                                        help="Logger output to stderr.")
 
-        if self.enable_logger:
+        if self.enabled_logger:
             add_optional_level()
             add_optional_stream()
             add_optional_format()
             add_optional_console()
 
     def __parse_logger(self, args: Namespace):
-        if not self.enable_logger:
+        if not self.enabled_logger:
             return
 
-        # save debug level to local variable
-        if hasattr(args, "_log_level_str_") and\
-           isinstance(args._log_level_str_, str):
-            level_name = args._log_level_str_.upper()
-            self.logger.setLevel(logging._nameToLevel[level_name])
-
-        def addHandler(handler: logging.Handler):
-            formatter: logging.Formatter = ColoredFormatter(
-                fmt=args._log_format_ if hasattr(args, "_log_format_")
-                and isinstance(args._log_format_, str) else None,
-                datefmt=None,
-                log_colors=DEFAULT_LOG_COLORS,
-                no_color=isinstance(handler, logging.FileHandler))
-            handler.setFormatter(formatter)
-            self.logger.addHandler(handler)
+        level_name: Optional[str] = args._log_level_str_.upper() if hasattr(
+            args, "_log_level_str_") and isinstance(
+            args._log_level_str_, str) else None
+        fmt: Optional[str] = args._log_format_ if hasattr(
+            args, "_log_format_") and isinstance(
+            args._log_format_, str) else None
 
+        handlers: List[logging.Handler] = []
         if hasattr(args, "_log_console_") and args._log_console_ is not None:
-            addHandler(logging.StreamHandler(stream=args._log_console_))
-
+            handlers.append(
+                log.new_stream_handler(stream=args._log_console_, fmt=fmt))
         if hasattr(args, "_log_files_"):
             for filename in args._log_files_:
-                assert isinstance(filename, str), \
-                    f"Unexpected type: {type(filename)}"
-                dirname: str = os.path.dirname(filename)
-                if not os.path.exists(dirname):
-                    os.makedirs(dirname)
-                addHandler(logging.FileHandler(filename))
+                handlers.append(
+                    log.new_file_handler(filename=filename, fmt=fmt))
+        self.initiate_logger(self.logger, level=level_name, handlers=handlers)
 
     def __add_parser(self, _map: Dict[add_command, argp],
                      arg_root: argp, cmd_root: add_command, **kwargs):
