@@ -2,8 +2,8 @@
 
 from urllib.parse import urljoin
 
-__name__ = "xarg-python"
-__version__ = "1.3.3"
+__project__ = "xarg-python"
+__version__ = "1.4.4"
 __description__ = "Simple command-line tool based on argparse."
 __url_home__ = "https://github.com/bondbox/xarg-python/"
 __url_code__ = __url_home__
